import random
import string
import datetime

from django import forms
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from common.forms import RenderableMixin
from marker.models import Marker, Tag


class SplitLifetimeWidget(forms.MultiWidget):
    def __init__(self, attrs=None, date_format=None, time_format=None):
        widgets = (forms.TextInput(attrs=attrs),
                   forms.Select(attrs=attrs, 
                                choices=(
                                    ('d', _('days')),
                                    ('w', _('weeks')), 
                                    ('y', _('years')))))
        super(SplitLifetimeWidget, self).__init__(widgets, attrs)

    def decompress(self, value):
        if value and len(value) >= 2:
            return [value[0:-2], value[-1]]
        return [None, None]

class AddMarkerForm(forms.ModelForm, RenderableMixin):
    lifetime = forms.CharField(label=_('Lifetime'), 
                               required=True, 
                               initial='1 year',
                               widget=SplitLifetimeWidget(attrs={'class': 'small'}), 
                               help_text=_('How long should the marker be visible on the map'))
    
    tags = forms.CharField(label=_('Tags (comma separated)'), required=False)
    
    class Meta:
        model = Marker
        fields = ('title', 'marker_type', 'content', 'more_info_url', 'lat', 'lng')
        
    def clean_lifetime(self):
        if self.get_timedelta() is None:
            raise forms.ValidationError(_('Lifetime has exceeded the maximum lifetime'))
        print self.get_timedelta()
        return self.cleaned_data.get('lifetime', '')
        
    def get_timedelta(self):
        lifetime = int(self.cleaned_data.get('lifetime')[3:-2].split('\', u\'')[0])
        lifetime_type = self.cleaned_data.get('lifetime')[3:-2].split('\', u\'')[1]
        timedelta = None
        
        if lifetime_type == 'd':
            timedelta = datetime.timedelta(days=lifetime)
        elif lifetime_type == 'w':
            print 'here'
            timedelta = datetime.timedelta(weeks=lifetime)
        elif lifetime_type == 'y':
            timedelta = datetime.timedelta(weeks=lifetime*52)

        if timedelta is None:
            timedelta = getattr(settings, 'DEFAULT_MARKER_LIFETIME')

        if timedelta > getattr(settings, 'MAX_MARKER_LIFETIME'):
            return None
        else:
            return timedelta
    
    def save(self, *args, **kwargs):
        self.instance.secret = ''.join(random.sample(string.letters+string.digits, 12))
        self.instance.expiration_date = datetime.date.today()
        super(AddMarkerForm, self).save(*args, **kwargs)
        for t in self.cleaned_data.get('tags').split(','):
            if t.strip() is not '':
                tag, created = Tag.objects.get_or_create(tag=t.strip())
                self.instance.tags.add(tag)
        self.instance.expiration_date = self.instance.update_date + self.get_timedelta()
        self.instance.save()
        return self.instance
        
        
