from django.db import models
from django.utils.translation import ugettext_lazy as _

class Tag(models.Model):
    tag = models.CharField(max_length=25)
    
    def __unicode__(self):
        return self.tag


class Type(models.Model):
    name = models.CharField(max_length=25)
    marker_icon = models.ImageField(upload_to='markers')
    template = models.FileField(upload_to='templates') # template and content dict should match and combined to HTML output
    
    def __unicode__(self):
        return self.name


class Marker(models.Model):
    lat = models.FloatField()
    lng = models.FloatField()
    marker_type = models.ForeignKey(Type)
    tags = models.ManyToManyField(Tag)
    title = models.CharField(max_length=50, verbose_name=_('Title'))
    content = models.TextField(verbose_name=('Content')) # json dictionary
    more_info_url = models.URLField(null=True, blank=True, verbose_name=_('Info URL'))
    secret = models.CharField(max_length=16)
    creation_date = models.DateField(auto_now_add=True)
    update_date = models.DateField(auto_now=True)
    expiration_date = models.DateField()
    
    def __unicode__(self):
        return '%s [%s, %s]' % (self.title, self.lat, self.lng)
